{% extends 'base.html' %}

{% block logout %}{% endblock %}
{% block selection %}{% endblock %}

{% block form %}
    <form action="/login" method="post" enctype="multipart/form-data">
        <label for="url">Panorama URL:</label>
        <input type="text" name="url" placeholder="https://<panorama_ip_address>" required><br>

        <label for="username">Username:</label>
        <input type="text" name="username" required><br>

        <label for="password">Password:</label>
        <input type="password" name="password" required><br>

        <input type="submit" value="Login">
    </form>
{% endblock %}